Introduction
============

Pipeline is an asset packaging library for Django, providing
both CSS and JavaScript concatenation and compression, built-in JavaScript
template support, and optional data-URI image and font embedding.

You can report bugs and discuss features on the `issues page <https://github.com/cyberdelia/django-pipeline/issues>`_.

Table Of Contents
=================

.. toctree::
   :maxdepth: 2
   
   installation
   configuration
   usage
   compressors
   compilers
   versioning
   templates
   storages
   signals
   using
   changelog

Indices and tables
==================

* :ref:`search`

